@@ -1,11 +1,11 @@
 ;;; spacious-padding.el --- Increase the padding/spacing of frames and windows -*- lexical-binding: t -*-
 
-;; Copyright (C) 2023-2024  Free Software Foundation, Inc.
+;; Copyright (C) 2023-2025  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/spacious-padding
-;; Version: 0.5.0
+;; Version: 0.6.0
 ;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: convenience, focus, writing, presentation
 
@@ -53,6 +53,18 @@
   :group 'faces
   :group 'frames)
 
+;; NOTE 2025-01-06: This is what `use-package' does with its own
+;; theme, so it is probably the right approach for us too.
+(eval-and-compile
+  ;; Declare a synthetic theme for :custom variables.
+  ;; Necessary in order to avoid having those variables saved by custom.el.
+  (deftheme spacious-padding))
+
+(enable-theme 'spacious-padding)
+;; Remove the synthetic spacious-padding theme from the enabled themes, so
+;; iterating over them to "disable all themes" won't disable it.
+(setq custom-enabled-themes (remq 'spacious-padding custom-enabled-themes))
+
 (defcustom spacious-padding-widths
   '( :internal-border-width 15
      :header-line-width 4
@@ -196,10 +208,10 @@ Examples of valid configurations:
   "Tab faces relevant to `spacious-padding-mode'.")
 
 (defvar spacious-padding--tab-line-faces
-  '(tab-line tab-line-tab tab-line-tab-inactive)
+  '(tab-line tab-line-tab tab-line-tab-inactive tab-line-tab-current)
   "Tab faces relevant to `spacious-padding-mode'.")
 
-(defun spacious-padding--get-right-divider-width (&optional no-fallback)
+(defun spacious-padding--get-window-divider-width (&optional no-fallback)
   "Get the width of window divider.
 With optional NO-FALLBACK return nil if there is no value.  Else return
 a reasonable fallback value."
@@ -270,7 +282,7 @@ overline."
   (list
    face
    `((t
-      ,(when (> (spacious-padding--get-right-divider-width) 1)
+      ,(when (> (spacious-padding--get-window-divider-width) 1)
          (list :background color :foreground color))))))
 
 (define-obsolete-function-alias
@@ -285,8 +297,10 @@ Ignore any arguments.  This is useful to add the function to abnormal
 hooks that pass one or more arguments to it, such as
 `after-make-frame-functions'."
   (let ((bg-main (face-background 'default))
-        (fg-main (face-foreground 'default)))
-    (custom-set-faces
+        (fg-main (face-foreground 'default))
+        custom--inhibit-theme-enable)
+    (custom-theme-set-faces
+     'spacious-padding
      `(fringe ((t :background ,bg-main)))
      `(line-number ((t :background ,bg-main)))
      `(header-line ((t ,@(spacious-padding-set-face-box-padding 'header-line 'default))))
@@ -302,6 +316,7 @@ hooks that pass one or more arguments to it, such as
      `(tab-line-tab ((t ,@(spacious-padding-set-face-box-padding 'tab-line-tab 'tab-line))))
      `(tab-line-tab-inactive ((t ,@(spacious-padding-set-face-box-padding 'tab-line-tab-inactive 'tab-line))))
      `(tab-line-tab-active ((t ,@(spacious-padding-set-face-box-padding 'tab-line-tab-active 'tab-line))))
+     `(tab-line-tab-current ((t ,@(spacious-padding-set-face-box-padding 'tab-line-tab-current 'tab-line))))
      `(vertical-border ((t :background ,bg-main :foreground ,bg-main)))
      `(,@(spacious-padding-set-window-divider 'window-divider bg-main))
      `(,@(spacious-padding-set-window-divider 'window-divider-first-pixel bg-main))
@@ -309,24 +324,26 @@ hooks that pass one or more arguments to it, such as
 
 (defun spacious-padding-unset-invisible-dividers ()
   "Make window dividers for THEME invisible."
-  (custom-set-faces
-   '(fringe (( )))
-   '(line-number (( )))
-   '(header-line (( )))
-   '(keycast-key (( )))
-   '(header-line-highlight (( )))
-   '(mode-line (( )))
-   '(mode-line-active (( )))
-   '(mode-line-inactive (( )))
-   '(mode-line-highlight (( )))
-   '(tab-bar-tab (( )))
-   '(tab-bar-tab-inactive (( )))
-   '(tab-line-tab (( )))
-   '(tab-line-tab-inactive (( )))
-   `(vertical-border (( )))
-   '(window-divider (( )))
-   '(window-divider-first-pixel (( )))
-   '(window-divider-last-pixel (( )))))
+  (let (custom--inhibit-theme-enable)
+    (custom-theme-set-faces
+     'spacious-padding
+     '(fringe (( )))
+     '(line-number (( )))
+     '(header-line (( )))
+     '(keycast-key (( )))
+     '(header-line-highlight (( )))
+     '(mode-line (( )))
+     '(mode-line-active (( )))
+     '(mode-line-inactive (( )))
+     '(mode-line-highlight (( )))
+     '(tab-bar-tab (( )))
+     '(tab-bar-tab-inactive (( )))
+     '(tab-line-tab (( )))
+     '(tab-line-tab-inactive (( )))
+     `(vertical-border (( )))
+     '(window-divider (( )))
+     '(window-divider-first-pixel (( )))
+     '(window-divider-last-pixel (( ))))))
 
 (defvar spacious-padding--internal-border-width nil
   "Default value of frame parameter `internal-border-width'.")
@@ -411,6 +428,7 @@ parameter values."
   (spacious-padding--store-default-parameters)
   (spacious-padding-modify-frame-parameters)
   (spacious-padding-set-faces)
+  (add-hook 'window-divider-mode-hook #'spacious-padding--enable-mode)
   (add-hook 'enable-theme-functions #'spacious-padding-set-faces)
   (add-hook 'after-make-frame-functions #'spacious-padding-set-parameters-of-frame))
 
@@ -418,6 +436,7 @@ parameter values."
   "Disable `spacious-padding-mode'."
   (spacious-padding-modify-frame-parameters :reset)
   (spacious-padding-unset-invisible-dividers)
+  (remove-hook 'window-divider-mode-hook #'spacious-padding--enable-mode)
   (remove-hook 'enable-theme-functions #'spacious-padding-set-faces)
   (remove-hook 'after-make-frame-functions #'spacious-padding-set-parameters-of-frame))
 
